OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Error" : "Error",
    "New note" : "Nueva nota",
    "Display mode for notes" : "Modo de visualización para notas",
    "Action" : "Acción",
    "Open in edit mode" : "Abrir en modo editor",
    "Open in preview mode" : "Abrir en modo de vista previa",
    "All notes" : "Todas la notas",
    "Categories" : "Categoría",
    "No notes yet" : "Aún no hay notas",
    "Share" : "Compartir",
    "Rename" : "Rename",
    "Delete note" : "Borrar nota",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Edit" : "Editar",
    "Preview" : "Vista previa",
    "Loading …" : "Cargando …",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "Last week" : "Semana pasada",
    "This month" : "Este mes",
    "Last month" : "Mes pasado",
    "Uncategorized" : "Sin categoría",
    "Tasks" : "Tareas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
